powered by
Adds two binary numbers. (x + y)
binAdd(x, y)
The sum of x and y. Returns a binary vector.
summand 1 (binary vector)
summand 2 (binary vector)
Little-Endian and unsigned is not supported at the moment. No floating point supported. if x or y is signed the return value will also be signed.
base::as.logical , base::is.logical, base::raw
five <- as.binary(5); ten <- as.binary(10); as.numeric(rdiversity:::binAdd(ten, five)) rdiversity:::binAdd(as.binary(c(0,1), logic=TRUE), as.binary(c(1,0), logic=TRUE))
Run the code above in your browser using DataLab