Functions to generate a metacommunity object.
metacommunity(partition, similarity)
# S4 method for class 'data.frame,missing'
metacommunity(partition)
# S4 method for class 'numeric,missing'
metacommunity(partition)
# S4 method for class 'matrix,missing'
metacommunity(partition)
# S4 method for class 'missing,similarity'
metacommunity(partition, similarity)
# S4 method for class 'numeric,similarity'
metacommunity(partition, similarity)
# S4 method for class 'data.frame,similarity'
metacommunity(partition, similarity)
# S4 method for class 'matrix,similarity'
metacommunity(partition, similarity)metacommunity() returns an object of class
metacommunity (see Fields).
type_abundancetwo-dimensional matrix of mode numeric
with rows as types (species), columns as subcommunities, and each
element containing the relative abundance of types in each subcommunity
relative to the metacommunity as a whole. In the phylogenetic case, this
corresponds to the proportional abundance of historical species, which is
calculated from the proportional abundance of terminal taxa
similaritytwo-dimensional matrix of mode numeric with
rows as types, columns as types, and elements containing pairwise
similarities between types
similarity_componentslist containing the components necessary to
calculate similarity. This list is empty when precompute_dist = TRUE
when calculating distance. When a pairwise distance matrix is too large and
precompute_dist = FALSE, this list contains all the information
required to calculate pairwise distance between types
similarity_parameterslist containing parameters associated with
converting pairwise distances to similarities (the dist2sim()
arguments)
ordinarinesstwo-dimensional matrix of mode numeric
with rows as types, columns as subcommunities, and elements containing the
ordinariness of types within subcommunities
subcommunity_weightsvector of mode numeric containing
subcommunity weights
type_weightstwo-dimensional matrix of mode numeric,
with rows as types, columns as subcommunities, and elements containing
weights of types within a subcommunity
dat_IDobject of class character denoting the type of diversity
being calculated. This can be "naive", "genetic", "taxonomic", and so on
raw_abundance[Phylogenetic] two-dimensional matrix of mode
numeric with rows as types, columns as subcommunities, and elements
containing the relative abundance of present day species
raw_structure[Phylogenetic] two-dimensional matrix of mode
numeric with rows as historical species, columns as present day
species, and elements containing historical species lengths within lineages
parameters[Phylogenetic] data.frame containing parameters
associated with each historic species in the phylogeny