gen2dist: Genetic distance matrix
Description
Converts a vcfR object to a matrix of pairwise genetic distances.
Usage
gen2dist(vcf, biallelic = FALSE)
Value
gen2dist(x) returns an object of class distance
containing a matrix of pairwise genetic distances.
Arguments
- vcf
object of class data.frame.
- biallelic
logical describing whether the data is biallelic or not (default).